@@ -11,11 +11,12 @@ from tiddlywebwiki.serialization import SPLITTER
 
 BASE_TIDDLYWIKI = 'tiddlywebwiki/resources/empty.html'
 config['base_tiddlywiki'] = BASE_TIDDLYWIKI
-environ = { 'tiddlyweb.config': config }
+environ = {'tiddlyweb.config': config}
 
 
 def test_html_attribute_escape_with_recipe():
-    tiddler = Tiddler('escape "double" quotes & &amp; in <tiddler> field values')
+    tiddler = Tiddler(
+            'escape "double" quotes & &amp; in <tiddler> field values')
     tiddler.bag = 'foo "bar" baz'
     tiddler.recipe = 'baz "bar" foo'
     tiddler.modifier = 'Chris "sensei" Dent'
@@ -25,17 +26,23 @@ def test_html_attribute_escape_with_recipe():
     serializer = Serializer('tiddlywebwiki.serialization', environ)
     serializer.object = tiddler
     string = serializer.to_string()
-    
-    assert r'''title="escape &quot;double&quot; quotes &amp; &amp;amp; in &lt;tiddler&gt; field values"''' in string
-    assert r'''server.title="escape &quot;double&quot; quotes &amp; &amp;amp; in &lt;tiddler&gt; field values"''' in string
-    assert r'''bag="foo &quot;bar&quot; baz"''' in string
-    assert r'''recipe="baz &quot;bar&quot; foo"''' in string
-    assert r'''server.workspace="bags/foo &quot;bar&quot; baz"''' in string
-    assert r'''modifier="Chris &quot;sensei&quot; Dent"''' in string
-    assert r'''creator="Chris &quot;sensei&quot; Dent"''' in string
-    assert r'''tags="foo [[xxx &quot;yyy&quot; zzz]]"''' in string
-    assert r'''custom="lorem 'ipsum' dolor &quot;sit&quot; amet"''' in string
-    assert r'''you may still <a href="http://our_test_domain:8001/recipes/baz%20%22bar%22%20foo/tiddlers">browse''' in string
+
+    assert ('title="escape &quot;double&quot; quotes &amp; '
+        '&amp;amp; in &lt;tiddler&gt; field values"' in string)
+    assert ('server.title="escape &quot;double&quot; quotes &amp; '
+        '&amp;amp; in &lt;tiddler&gt; field values"' in string)
+    assert 'bag="foo &quot;bar&quot; baz"' in string
+    assert 'recipe="baz &quot;bar&quot; foo"' in string
+    assert 'server.workspace="bags/foo &quot;bar&quot; baz"' in string
+    assert 'modifier="Chris &quot;sensei&quot; Dent"' in string
+    assert 'creator="Chris &quot;sensei&quot; Dent"' in string
+    assert 'tags="foo [[xxx &quot;yyy&quot; zzz]]"' in string
+    assert '''custom="lorem 'ipsum' dolor &quot;sit&quot; amet"''' in string
+    # single tiddler's browse link is that tiddler in its bag
+    assert ('you may still <a href="/bags/foo%20%22bar%22%20baz/tiddlers'
+            '/escape%20%22double%22%20quotes%20%26%20%26amp%3B%20in%20%3C'
+            'tiddler%3E%20field%20values">browse' in string)
+
 
 def test_html_attribute_escape_with_bag():
     tiddler = Tiddler('escape "double" quotes in tiddler field values')
@@ -48,15 +55,20 @@ def test_html_attribute_escape_with_bag():
     serializer.object = tiddler
     string = serializer.to_string()
 
-    assert r'''title="escape &quot;double&quot; quotes in tiddler field values"''' in string
-    assert r'''server.title="escape &quot;double&quot; quotes in tiddler field values"''' in string
-    assert r'''bag="foo &quot;bar&quot; baz"''' in string
-    assert r'''server.workspace="bags/foo &quot;bar&quot; baz"''' in string
-    assert r'''modifier="Chris &quot;sensei&quot; Dent"''' in string
-    assert r'''creator="Chris &quot;sensei&quot; Dent"''' in string
-    assert r'''tags="foo [[xxx &quot;yyy&quot; zzz]]"''' in string
-    assert r'''custom="lorem 'ipsum' dolor &quot;sit&quot; amet"''' in string
-    assert r'''you may still <a href="http://our_test_domain:8001/bags/foo%20%22bar%22%20baz/tiddlers">browse''' in string
+    assert ('title="escape &quot;double&quot; quotes in tiddler field values"'
+        in string)
+    assert ('server.title="escape &quot;double&quot; quotes in tiddler '
+        'field values"' in string)
+    assert 'bag="foo &quot;bar&quot; baz"' in string
+    assert 'server.workspace="bags/foo &quot;bar&quot; baz"' in string
+    assert 'modifier="Chris &quot;sensei&quot; Dent"' in string
+    assert 'creator="Chris &quot;sensei&quot; Dent"' in string
+    assert 'tags="foo [[xxx &quot;yyy&quot; zzz]]"' in string
+    assert '''custom="lorem 'ipsum' dolor &quot;sit&quot; amet"''' in string
+    # single tiddler's browse link is that tiddler in its bag
+    assert ('you may still <a href="/bags/foo%20%22bar%22%20baz/tiddlers/'
+            'escape%20%22double%22%20quotes%20in%20tiddler%20field%20'
+            'values">browse' in string)
 
 
 def test_content_type():
@@ -66,16 +78,18 @@ def test_content_type():
     string = serializer.to_string()
     tiddler = _extract_tiddler('Foo', string)
 
-    assert r'''server.content-type=""''' in tiddler
+    assert 'server.content-type=""' in tiddler
 
     tiddler = Tiddler('_Foo', 'Alpha')
-    tiddler.type = 'None' # possible weirdness in the text serialization and some stores
+    # possible weirdness in the text serialization and some stores
+    # with empty type field being set to a string
+    tiddler.type = 'None'
     serializer = Serializer('tiddlywebwiki.serialization', environ)
     serializer.object = tiddler
     string = serializer.to_string()
     tiddler = _extract_tiddler('_Foo', string)
 
-    assert r'''server.content-type=""''' in tiddler
+    assert 'server.content-type=""' in tiddler
 
     tiddler = Tiddler('Bar', 'Bravo')
     tiddler.type = 'text/x-custom'
@@ -85,8 +99,8 @@ def test_content_type():
     string = serializer.to_string()
     tiddler = _extract_tiddler('Bar', string)
 
-    assert r'''server.content-type="text/x-custom"''' in tiddler
-    assert r'''<pre>lorem ipsum dolor sit amet</pre>''' in tiddler
+    assert 'server.content-type="text/x-custom"' in tiddler
+    assert '<pre>lorem ipsum dolor sit amet</pre>' in tiddler
 
     tiddler = Tiddler('Baz', 'Charlie')
     tiddler.type = 'application/x-custom'
@@ -95,9 +109,9 @@ def test_content_type():
     serializer.object = tiddler
     string = serializer.to_string()
     tiddler = _extract_tiddler('Baz', string)
-    tiddler_text = tiddler.split("<pre>", 1)[1].split("</pre>", 1)[0].strip()
 
-    assert r'''server.content-type="application/x-custom"''' in tiddler
+    assert 'server.content-type="application/x-custom"' in tiddler
+
 
 def test_server_etag():
     tiddler = Tiddler('Foo', 'Alpha')
@@ -106,7 +120,8 @@ def test_server_etag():
     string = serializer.to_string()
     tiddler = _extract_tiddler('Foo', string)
 
-    assert r'''server.etag="&quot;Alpha/Foo/''' in tiddler
+    assert 'server.etag="&quot;Alpha/Foo/' in tiddler
+
 
 def _extract_tiddler(title, wiki):
     """
